"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SeleniumWebdriver = void 0;
const messages_js_1 = require("../messages.js");
const webdriver_js_1 = require("../webdriver.js");
const logger_js_1 = require("../logger.js");
// TODO Update context interface through references
class SeleniumWebdriver extends webdriver_js_1.CreeveyWebdriverBase {
    #browser = null;
    #browserName;
    #gridUrl;
    #config;
    #options;
    constructor(browser, gridUrl, config, options) {
        super();
        this.#browserName = browser;
        this.#gridUrl = gridUrl;
        this.#config = config;
        this.#options = options;
        (0, messages_js_1.subscribeOn)('shutdown', () => {
            void this.#browser?.closeBrowser().finally(() => process.exit());
            this.#browser = null;
        });
    }
    get browser() {
        return this.#browser?.browser;
    }
    getSessionId() {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.browser.getSession().then((session) => session.getId());
    }
    async openBrowser(fresh = false) {
        if (this.#browser) {
            if (fresh) {
                await this.#browser.closeBrowser();
                this.#browser = null;
            }
            else {
                return this;
            }
        }
        const internalModule = await (async () => {
            try {
                return await import('./internal.js');
            }
            catch (error) {
                logger_js_1.logger.error(error);
                return null;
            }
        })();
        if (!internalModule)
            return null;
        const { InternalBrowser } = internalModule;
        const browser = await InternalBrowser.getBrowser(this.#browserName, this.#gridUrl, this.#config, this.#options);
        if (!browser)
            return null;
        this.#browser = browser;
        return this;
    }
    async closeBrowser() {
        if (this.#browser) {
            await this.#browser.closeBrowser();
            this.#browser = null;
        }
    }
    async loadStoriesFromBrowser() {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.loadStoriesFromBrowser();
    }
    afterTest(test) {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.afterTest(test);
    }
    async takeScreenshot(captureElement, ignoreElements) {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.takeScreenshot(captureElement, ignoreElements);
    }
    waitForComplete(callback) {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        this.#browser.waitForComplete(callback);
    }
    async selectStory(id, waitForReady) {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.selectStory(id, waitForReady);
    }
    async updateStoryArgs(story, updatedArgs) {
        if (!this.#browser) {
            // TODO Describe the error
            throw new Error('Browser is not initialized');
        }
        return this.#browser.updateStoryArgs(story, updatedArgs);
    }
}
exports.SeleniumWebdriver = SeleniumWebdriver;
//# sourceMappingURL=webdriver.js.map